import React, { PropTypes } from 'react';
import classNames from 'classnames';

const ALERT_TYPES = [
  'info',
  'warning',
  'error',
  'success'
];

const propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  dismissible: PropTypes.bool,
  type: PropTypes.oneOf(ALERT_TYPES)
};

const defaultProps = {
  type: ALERT_TYPES[0]
};

class Alert extends React.Component {
  constructor(props) {
    super(props);

    this.state = { dismissed: false };
    this.handleDismiss = this.handleDismiss.bind(this);
  }

  handleDismiss() {
    this.setState({ dismissed: true });
  }

  renderDismissBtn(dismissible) {
    if (dismissible) return (
      <button
        className="Alert-dismiss"
        onClick={this.handleDismiss}>
        Dismiss
      </button>
    );

    return null;
  }

  render() {
    const {children, className, dismissible, type} = this.props;
    const classes = classNames(
      'Alert',
      `Alert--${type}`,
      className
    );

    if (this.state.dismissed) return null;

    return (
      <div className={classes}>
        {children}
        {this.renderDismissBtn(dismissible)}
      </div>
    );
  }
}

Alert.propTypes    = propTypes;
Alert.defaultProps = defaultProps;

export default Alert;
