import chai, { expect } from 'chai';
import chaiEnzyme from 'chai-enzyme';
import React from 'react';
import { shallow } from 'enzyme';

import Alert from './index';

chai.use(chaiEnzyme());

describe('Alert', () => {
  let sut;

  beforeEach(() => {
    sut = shallow(<Alert />);
  });

  it('should exist with `Alert` class name', () => {
    expect(sut.find('div.Alert')).to.exist;
  });

  it('should not have a dismiss button by default', () => {
    expect(sut.find('button.Alert-dismiss')).to.not.exist;
  });

  describe('when children are passed in', () => {
    beforeEach(() => {
      sut = shallow(<Alert>Fancy Alert Message!</Alert>);
    });

    it('should render the children', () => {
      expect(sut).to.contain('Fancy Alert Message!');
    });
  });

  describe('when given a className property', () => {
    beforeEach(() => {
      sut = shallow(<Alert className="MyCustomAlert" />);
    });

    it('should render with the root & given class names', () => {
      expect(sut).to.have.className('Alert');
      expect(sut).to.have.className('MyCustomAlert');
    });
  });

  describe('when given a type property', () => {
    beforeEach(() => {
      sut = shallow(<Alert type="success" />);
    });

    it('should render with the root & type in the class name', () => {
      expect(sut).to.have.className('Alert');
      expect(sut).to.have.className('Alert--success');
    });
  });

  describe('when given dismissible property', () => {
    beforeEach(() => {
      sut = shallow(<Alert dismissible />);
    });

    it('should render dismiss button with Alert-dismiss classname', () => {
      expect(sut).to.have.exactly(1).descendants('button.Alert-dismiss');
    });

    describe('when dismiss button is clicked', () => {
      beforeEach(() => {
        sut.find('button.Alert-dismiss').simulate('click');
      });

      it('should update the dismissed property on the state', () => {
        expect(sut).to.have.state('dismissed', true);
      });

      it('should render nothing', () => {
        expect(sut).to.be.empty;
      });
    });
  });
});
